autowisp.astrometry.anmatch_transformation module — AutoWISP documentation

# autowisp.astrometry.anmatch_transformation module

## Class Inheritance Diagram

Define a class to apply sky-to-frame transformations found by anmatch.

class autowisp.astrometry.anmatch_transformation.AnmatchTransformation(trans_file=None)

  Bases: `object`

  A clas that applies transformations generated by anmatch.

  __call__(sources, save_intermediate=False)

    Return the x and y coordinates to which the given (ra, dec) project to.

    Parameters:

      - sources – The sky position to project to frame coordinates. Should have keys named ‘RA’ and ‘Dec’ in degrees.

      - save_intermediate – Should the intermediate coordinates be saved. Those are the coordinates after apllying the sky projection and before applying the polynomial transformation.

    Returns:

      The position in pixels relative to the lower left frame of the corner to which the given sky position projects under the currently defined transformation, as a numpy array with fields named ‘x’ and ‘y’. If save_intermediate is True, the result also contains fields called ‘xi’ and ‘eta’ containing the intermediate coordinates.

    Return type:

      numpy.array(dtype=[(‘x’, float), (‘y’, float)])

  __init__(trans_file=None)

    Parse the transformation to apply from the given file.

    Parameters:

      trans_file – The transformation file contaning the transformation to apply. If this is the name of an existing file, it is opened and parsed, otherwise this should be a sequence of the lines contained in the transfomation file.

    Returns:

      None

  evaluate_polynomial(projected, transformed)

    Apply the currently defined polynomial transfomation to (xi, eta).

    Parameters:

      - projected – The projected (c.f. gnomonic_projection()) coordinates to transform. Should have ‘xi’ and ‘eta’ keys containing the projected coordinates to transform in degrees.

      - transformed – A numpy array with ‘x’ and ‘y’ fields to fill with the transformed coordinates (in pixels).

    Returns:

      None

  read_anmatch_transformation(trans_lines)

    Parse the transformation to apply from the given file.

    Parameters:

      trans_lines – A sequence of the individual lines of the trans file defining the transformation to apply.

    Returns:

      None